#!/usr/bin/perl
use lib 'lib';
use strict;
use Config::Simple::Conf;
use Data::Dumper;

print Dumper(Config::Simple::Conf->new($ARGV[0] || "example/test_inc.conf"));
